@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -19,9 +22,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-lambda-sqs-lambda",
-    "2.54.0",
+    "2.58.0",
     __name__[0:-6],
-    "aws-lambda-sqs-lambda@2.54.0.jsii.tgz",
+    "aws-lambda-sqs-lambda@2.58.0.jsii.tgz",
 )
 
 __all__ = [
